commando.impl.command-map


coll-starts-with?clj/s

(coll-starts-with? coll coll-prefix)

Returns true if coll starts with all elements of coll-prefix, in order. Works on any indexed, counted collection (vectors, arrays, strings). Uses indexed loop instead of seq/take to avoid lazy sequence allocation.

Examples: (coll-starts-with? [:a :b :c] [:a :b]) ;=> true (coll-starts-with? [:a :b :c] [:a :x]) ;=> false (coll-starts-with? [:a :b :c] [:a :b :c :d]) ;=> false (coll-starts-with? [:a :b] []) ;=> true (coll-starts-with? nil [:a]) ;=> false

Returns true if `coll` starts with all elements of `coll-prefix`, in order.
Works on any indexed, counted collection (vectors, arrays, strings).
Uses indexed loop instead of seq/take to avoid lazy sequence allocation.

Examples:
  (coll-starts-with? [:a :b :c] [:a :b])        ;=> true
  (coll-starts-with? [:a :b :c] [:a :x])        ;=> false
  (coll-starts-with? [:a :b :c] [:a :b :c :d])  ;=> false
  (coll-starts-with? [:a :b] [])                ;=> true
  (coll-starts-with? nil [:a])                  ;=> false
sourceraw docstring

command-dataclj/s

(command-data p)
source

command-idclj/s

(command-id p)
source

command-map-pathclj/s

(command-map-path path data)

Constructs a CommandMapPath with cached hash for fast map/set lookups.

Constructs a CommandMapPath with cached hash for fast map/set lookups.
sourceraw docstring

command-map?clj/s

(command-map? obj)
source

command-pathclj/s

(command-path p)
source

CommandMapSpecclj/s

source

start-with?clj/s

(start-with? p1 p2)
source

validate-command-specclj/s

(validate-command-spec spec)

Validates a command spec and returns either the spec or an error map. Returns {:error explanation} if validation fails.

Validates a command spec and returns either the spec or an error map.
Returns {:error explanation} if validation fails.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries