commando.impl.dependency


build-dependency-graphclj/s

(build-dependency-graph instruction cm-list path-trie)

Builds forward dependency graph using a pre-built path-trie. Returns {CommandMapPath -> #{deps}}.

Builds forward dependency graph using a pre-built path-trie.
Returns {CommandMapPath -> #{deps}}.
sourceraw docstring

find-command-dependenciesclj/smultimethod

Finds command dependencies based on dependency-type.

Returns a set of CommandMapPath objects that must execute before the given command.

Modes:

  • :all-inside - depends on all commands inside the Command: if it Map - the values, if it Vector - elements of vectors
  • :point - depends on command(s) at a specific path, defined by :point-key setting key. :point collect only one depedency - the only one it refering.
  • :none - no dependencies (not implemented, returns empty set by default)
Finds command dependencies based on dependency-type.

Returns a set of CommandMapPath objects that must execute before the given command.

Modes:
- :all-inside - depends on all commands inside the Command:
   if it Map - the values, if it Vector - elements of vectors
- :point - depends on command(s) at a specific path, defined by :point-key
    setting key. :point collect only one depedency - the only one it refering.
- :none - no dependencies (not implemented, returns empty set by default)
sourceraw docstring

path-exists-in-instruction?clj/s

(path-exists-in-instruction? instruction path)

Checks if a path exists in the instruction map.

Checks if a path exists in the instruction map.
sourceraw docstring

point-target-pathclj/s

(point-target-path instruction command-path-obj)

Returns the target path for a :point dependency, resolving relative navigation.

Returns the target path for a :point dependency, resolving relative navigation.
sourceraw docstring

resolve-relative-pathclj/s

(resolve-relative-path instruction base-path segments)

Resolves path segments with relative navigation against a base path. Returns nil if an @anchor segment cannot be resolved.

Supported segment types: "../" - go up one level from current position "./" - stay at current level (noop for relative base) "@anchor" - jump to nearest ancestor with matching __anchor name (requires instruction to be passed as first argument) any other - descend into that key

Resolves path segments with relative navigation against a base path.
Returns nil if an @anchor segment cannot be resolved.

Supported segment types:
  "../"        - go up one level from current position
  "./"         - stay at current level (noop for relative base)
  "@anchor"    - jump to nearest ancestor with matching __anchor name
                  (requires instruction to be passed as first argument)
  any other      - descend into that key
sourceraw docstring

throw-point-errorclj/s

(throw-point-error command-path-obj target-path instruction)

Throws a standardized error for missing point dependencies.

Throws a standardized error for missing point dependencies.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries