API for registry.
A registry is a vector-based collection of command specifications that define how to recognize, validate, and execute commands found in instruction map. Vector order defines the command scan priority.
Input (user-facing): (registry/build [cmds/command-from-spec cmds/command-fn-spec])
Output (built registry): {:registry [command-from-spec command-fn-spec] :registry-validated 1709654400000 :registry-hash 12345}
API for registry.
A registry is a vector-based collection of command specifications that define how to
recognize, validate, and execute commands found in instruction map.
Vector order defines the command scan priority.
Input (user-facing):
(registry/build
[cmds/command-from-spec cmds/command-fn-spec])
Output (built registry):
{:registry [command-from-spec command-fn-spec]
:registry-validated 1709654400000
:registry-hash 12345}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |