(coll-starts-with? coll coll-prefix)Returns true if coll starts with all elements of coll-prefix, in order.
Works on any indexed, counted collection (vectors, arrays, strings).
Uses indexed loop instead of seq/take to avoid lazy sequence allocation.
Examples: (coll-starts-with? [:a :b :c] [:a :b]) ;=> true (coll-starts-with? [:a :b :c] [:a :x]) ;=> false (coll-starts-with? [:a :b :c] [:a :b :c :d]) ;=> false (coll-starts-with? [:a :b] []) ;=> true (coll-starts-with? nil [:a]) ;=> false
Returns true if `coll` starts with all elements of `coll-prefix`, in order. Works on any indexed, counted collection (vectors, arrays, strings). Uses indexed loop instead of seq/take to avoid lazy sequence allocation. Examples: (coll-starts-with? [:a :b :c] [:a :b]) ;=> true (coll-starts-with? [:a :b :c] [:a :x]) ;=> false (coll-starts-with? [:a :b :c] [:a :b :c :d]) ;=> false (coll-starts-with? [:a :b] []) ;=> true (coll-starts-with? nil [:a]) ;=> false
(command-map-path path data)Constructs a CommandMapPath with cached hash for fast map/set lookups.
Constructs a CommandMapPath with cached hash for fast map/set lookups.
(validate-command-spec spec)Validates a command spec and returns either the spec or an error map. Returns {:error explanation} if validation fails.
Validates a command spec and returns either the spec or an error map.
Returns {:error explanation} if validation fails.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |