(build-dependency-graph instruction cm-list)Builds the dependency map for all commands in cm-list.
Returns a map from CommandMapPath objects to their dependency sets.
Builds the dependency map for all commands in `cm-list`. Returns a map from CommandMapPath objects to their dependency sets.
Finds command dependencies based on dependency-type.
Returns a set of CommandMapPath objects that must execute before the given command.
Modes:
Finds command dependencies based on dependency-type.
Returns a set of CommandMapPath objects that must execute before the given command.
Modes:
- :all-inside - depends on all commands inside the Command:
if it Map - the values, if it Vector - elements of vectors
- :all-inside-recur - depends on all commands nested within this command's path
- :point - depends on command(s) at a specific path, defined by :point-key
setting key. :point collect only one depedency - the only one it refering.
- :point-and-all-inside-recur - joined approach of :point and :all-inside-recur.
collect dependencies for path it pointing along with nested dependecies under
the pointed item. First tries to find a command at the exact target path. If not found,
walks up the path hierarchy to find parent commands that will create/modify
the target path.
- :none - no dependencies (not implemented, returns empty set by default)(path-exists-in-instruction? instruction path)Checks if a path exists in the instruction map.
Checks if a path exists in the instruction map.
(point-target-path instruction command-path-obj)Returns the target path for a :point dependency, resolving relative navigation.
Returns the target path for a :point dependency, resolving relative navigation.
(resolve-relative-path instruction base-path segments)Resolves path segments with relative navigation against a base path. Returns nil if an @anchor segment cannot be resolved.
Supported segment types: "../" - go up one level from current position "./" - stay at current level (noop for relative base) "@anchor" - jump to nearest ancestor with matching __anchor name (requires instruction to be passed as first argument) any other - descend into that key
Resolves path segments with relative navigation against a base path.
Returns nil if an @anchor segment cannot be resolved.
Supported segment types:
"../" - go up one level from current position
"./" - stay at current level (noop for relative base)
"@anchor" - jump to nearest ancestor with matching __anchor name
(requires instruction to be passed as first argument)
any other - descend into that key(throw-point-error command-path-obj target-path instruction)Throws a standardized error for missing point dependencies.
Throws a standardized error for missing point dependencies.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |