API for registry.
A registry is a vector-based collection of command specifications that define how to recognize, validate, and execute commands found in instruction map. Vector order defines the command scan priority.
Input (user-facing): (registry/build [cmds/command-from-spec cmds/command-fn-spec])
Output (built registry): {:registry [command-from-spec command-fn-spec] :registry-validated 1709654400000 :registry-hash 12345}
API for registry.
A registry is a vector-based collection of command specifications that define how to
recognize, validate, and execute commands found in instruction map.
Vector order defines the command scan priority.
Input (user-facing):
(registry/build
[cmds/command-from-spec cmds/command-fn-spec])
Output (built registry):
{:registry [command-from-spec command-fn-spec]
:registry-validated 1709654400000
:registry-hash 12345}(build specs-vec)Builds a command registry from a vector of CommandMapSpecs.
Args: specs-vec - A vector of CommandMapSpec maps, each with at least :type
Returns: A validated registry map with :registry vector, or throws an error
Builds a command registry from a vector of CommandMapSpecs. Args: specs-vec - A vector of CommandMapSpec maps, each with at least :type Returns: A validated registry map with :registry vector, or throws an error
(built? registry)Returns true if the given value is a properly built registry map.
Returns true if the given value is a properly built registry map.
(registry-add built-registry command-map-spec)Adds or replaces a spec in a built registry (identified by :type). Revalidates.
Adds or replaces a spec in a built registry (identified by :type). Revalidates.
(registry-remove built-registry command-map-spec-type)Removes a spec from a built registry by its :type. Revalidates.
Removes a spec from a built registry by its :type. Revalidates.
(remove-runtime-registry-commands-from-command-list cm-vector)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |